@@ -1,3 +1,5 @@
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
+
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
@@ -11,8 +13,8 @@
  * GNU Lesser General Public License for more details.
  * You should have received a copy of the GNU Lesser General Public License
  * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
-
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ *
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #include "seed-private.h"
@@ -45,14 +47,16 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
   SeedNativeClosure *privates = userdata;
   gint num_args, i;
   JSValueRef *jsargs;
-  JSValueRef return_value;
-  JSValueRef exception = 0;
+  JSValueRef return_value, exception = 0;
   GITypeTag return_tag;
   GIArgInfo *arg_info;
   GITypeInfo *return_type;
-  GArgument rarg;
-  GArgument return_arg;
+  GITypeInfo *arg_type;
+  GITypeTag tag;
+  GArgument rarg, return_arg;
   JSContextRef ctx = JSGlobalContextCreateInGroup (context_group, 0);
+  GArgument *arg = &rarg;
+  gchar *mes;
 
   seed_prepare_global_context (ctx);
 
@@ -66,9 +70,6 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 
   for (i = 0; i < num_args; i++)
     {
-      GITypeInfo *arg_type;
-      GITypeTag tag;
-      GArgument *arg = &rarg;
 
       arg_info = g_callable_info_get_arg (privates->info, i);
       arg_type = g_arg_info_get_type (arg_info);
@@ -175,8 +176,7 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 
   if (exception)
     {
-      gchar *mes = seed_exception_to_string (ctx,
-					     exception);
+      mes = seed_exception_to_string (ctx, exception);
       g_warning ("Exception in closure marshal. %s \n", mes);
       g_free (mes);
       exception = 0;
@@ -275,8 +275,7 @@ seed_handle_closure (ffi_cif * cif, void *result, void **args, void *userdata)
 SeedNativeClosure *
 seed_make_native_closure (JSContextRef ctx,
 			  GICallableInfo * info,
-			  GIArgInfo *arg_info,
-			  JSValueRef function)
+			  GIArgInfo * arg_info, JSValueRef function)
 {
   ffi_cif *cif;
   ffi_closure *closure;
@@ -302,11 +301,14 @@ seed_make_native_closure (JSContextRef ctx,
 
   privates = g_new0 (SeedNativeClosure, 1);
   privates->info = (GICallableInfo *) g_base_info_ref ((GIBaseInfo *) info);
-  privates->arg_info = (GIArgInfo *) g_base_info_ref ((GIBaseInfo *) arg_info);
+  privates->arg_info =
+    (GIArgInfo *) g_base_info_ref ((GIBaseInfo *) arg_info);
   privates->function = function;
   privates->cif = cif;
 
-  closure = g_callable_info_prepare_closure (info, cif, seed_handle_closure, privates);
+  closure =
+    g_callable_info_prepare_closure (info, cif, seed_handle_closure,
+				     privates);
   privates->closure = closure;
 
   JSValueProtect (ctx, function);
@@ -328,8 +330,9 @@ closure_invalidated (gpointer data, GClosure * c)
   SeedClosure *closure = (SeedClosure *) c;
 
   SEED_NOTE (FINALIZATION, "Finalizing closure.");
-  if (closure->user_data && !JSValueIsUndefined(eng->context, closure->user_data))
-    JSValueUnprotect(eng->context, closure->user_data);
+  if (closure->user_data
+      && !JSValueIsUndefined (eng->context, closure->user_data))
+    JSValueUnprotect (eng->context, closure->user_data);
   if (!JSValueIsUndefined (eng->context, closure->function))
     JSValueUnprotect (eng->context, closure->function);
 
@@ -338,48 +341,60 @@ closure_invalidated (gpointer data, GClosure * c)
 }
 
 JSObjectRef
-seed_closure_get_callable (GClosure *c)
+seed_closure_get_callable (GClosure * c)
 {
-  return ((SeedClosure *)c)->function;
+  return ((SeedClosure *) c)->function;
 }
 
 JSValueRef
-seed_closure_invoke (GClosure *closure, JSValueRef *args, guint argc, JSValueRef *exception)
+seed_closure_invoke (GClosure * closure, JSValueRef * args, guint argc,
+		     JSValueRef * exception)
 {
   JSContextRef ctx = JSGlobalContextCreateInGroup (context_group, 0);
-  JSValueRef *real_args = g_newa (JSValueRef, argc +1);
+  JSValueRef *real_args = g_newa (JSValueRef, argc + 1);
   JSValueRef ret;
   guint i;
 
   seed_prepare_global_context (ctx);
   for (i = 0; i < argc; i++)
     real_args[i] = args[i];
-  args[argc] = ((SeedClosure *)closure)->user_data ? ((SeedClosure *)closure)->user_data : JSValueMakeNull (ctx);
+  args[argc] =
+    ((SeedClosure *) closure)->user_data ? ((SeedClosure *) closure)->
+    user_data : JSValueMakeNull (ctx);
 
-  ret = JSObjectCallAsFunction (ctx, ((SeedClosure *)closure)->function, NULL, argc+1, real_args, exception);
+  ret =
+    JSObjectCallAsFunction (ctx, ((SeedClosure *) closure)->function, NULL,
+			    argc + 1, real_args, exception);
   JSGlobalContextRelease ((JSGlobalContextRef) ctx);
 
   return ret;
 }
 
 JSValueRef
-seed_closure_invoke_with_context (JSContextRef ctx, GClosure *closure, JSValueRef *args, guint argc, JSValueRef *exception)
+seed_closure_invoke_with_context (JSContextRef ctx, GClosure * closure,
+				  JSValueRef * args, guint argc,
+				  JSValueRef * exception)
 {
-  JSValueRef *real_args = g_newa (JSValueRef, argc +1);
+  JSValueRef *real_args = g_newa (JSValueRef, argc + 1);
   JSValueRef ret;
   guint i;
 
   for (i = 0; i < argc; i++)
     real_args[i] = args[i];
-  args[argc] = ((SeedClosure *)closure)->user_data ? ((SeedClosure *)closure)->user_data : JSValueMakeNull (ctx);
+  args[argc] =
+    ((SeedClosure *) closure)->user_data ? ((SeedClosure *) closure)->
+    user_data : JSValueMakeNull (ctx);
 
-  ret = JSObjectCallAsFunction (ctx, ((SeedClosure *)closure)->function, NULL, argc+1, real_args, exception);
+  ret =
+    JSObjectCallAsFunction (ctx, ((SeedClosure *) closure)->function, NULL,
+			    argc + 1, real_args, exception);
 
   return ret;
 }
 
 GClosure *
-seed_closure_new (JSContextRef ctx, JSObjectRef function, JSObjectRef user_data, const gchar *description)
+seed_closure_new (JSContextRef ctx, JSObjectRef function,
+		  JSObjectRef user_data, const gchar * description)
 {
   GClosure *closure;
 
@@ -392,7 +407,7 @@ seed_closure_new (JSContextRef ctx, JSObjectRef function, JSObjectRef user_data,
   if (user_data && !JSValueIsNull (ctx, user_data))
     {
       ((SeedClosure *) closure)->user_data = user_data;
-      JSValueProtect(ctx, user_data);
+      JSValueProtect (ctx, user_data);
     }
 
   if (description)
@@ -402,17 +417,19 @@ seed_closure_new (JSContextRef ctx, JSObjectRef function, JSObjectRef user_data,
 }
 
 void
-seed_closure_warn_exception (GClosure *c,
-			     JSContextRef ctx,
-			     JSValueRef exception)
+seed_closure_warn_exception (GClosure * c,
+			     JSContextRef ctx, JSValueRef exception)
 {
   JSObjectRef callable = seed_closure_get_callable (c);
   gchar *name = seed_value_to_string (ctx,
-				      seed_object_get_property (ctx, callable, "name"),
+				      seed_object_get_property (ctx, callable,
+								"name"),
 				      NULL);
   gchar *mes = seed_exception_to_string (ctx, exception);
 
-  g_warning("Exception in closure (%p) for %s (handler %s). %s", c, ((SeedClosure *)c)->description, *name == '\0' ? "[anonymous]" : name, mes);
+  g_warning ("Exception in closure (%p) for %s (handler %s). %s", c,
+	     ((SeedClosure *) c)->description,
+	     *name == '\0' ? "[anonymous]" : name, mes);
 
   g_free (name);
   g_free (mes);
