@@ -76,6 +76,8 @@ SeedEngine *seed_init (gint *argc, gchar ***argv);
 SeedEngine *seed_init_with_context_group (gint *argc, gchar ***argv,
 					  SeedContextGroup group);
 
+void seed_engine_destroy (SeedEngine *eng);
+
 SeedValue seed_simple_evaluate (SeedContext ctx,
 				gchar * source,
 				SeedException *exception);
@@ -105,6 +107,7 @@ SeedGlobalContext seed_context_create (SeedContextGroup group,
 				       SeedClass global_class);
 SeedGlobalContext seed_context_ref (SeedGlobalContext ctx);
 void seed_context_unref (SeedGlobalContext ctx);
+void seed_context_collect (SeedGlobalContext ctx);
 
 SeedObject seed_context_get_global_object (SeedContext ctx);
 
